diff --git a/artemis-boot/src/main/java/org/apache/activemq/artemis/boot/ActiveMQ.java b/artemis-boot/src/main/java/org/apache/activemq/artemis/boot/Artemis.java
similarity index 95%
rename from artemis-boot/src/main/java/org/apache/activemq/artemis/boot/ActiveMQ.java
rename to artemis-boot/src/main/java/org/apache/activemq/artemis/boot/Artemis.java
index 5182c54b34..bf83100f15 100644
--- a/artemis-boot/src/main/java/org/apache/activemq/artemis/boot/ActiveMQ.java
+++ b/artemis-boot/src/main/java/org/apache/activemq/artemis/boot/Artemis.java
@@ -32,19 +32,19 @@ import java.util.Comparator;
* execution off to the ActiveMQ cli main.
*
*/
-public class ActiveMQ
+public class Artemis
{
public static void main(String[] args) throws Throwable
{
ArrayList dirs = new ArrayList();
- String instance = System.getProperty("activemq.instance");
+ String instance = System.getProperty("artemis.instance");
if (instance != null)
{
dirs.add(new File(new File(instance), "lib"));
}
- String home = System.getProperty("activemq.home");
+ String home = System.getProperty("artemis.home");
if (home != null)
{
dirs.add(new File(new File(home), "lib"));
@@ -98,7 +98,7 @@ public class ActiveMQ
// Now setup our classloader..
URLClassLoader loader = new URLClassLoader(urls.toArray(new URL[urls.size()]));
Thread.currentThread().setContextClassLoader(loader);
- Class> clazz = loader.loadClass("org.apache.activemq.artemis.cli.ActiveMQ");
+ Class> clazz = loader.loadClass("org.apache.activemq.artemis.cli.Artemis");
Method method = clazz.getMethod("main", args.getClass());
try
{
diff --git a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/ActiveMQ.java b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/Artemis.java
similarity index 87%
rename from artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/ActiveMQ.java
rename to artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/Artemis.java
index 194ad44c96..1b747c5183 100644
--- a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/ActiveMQ.java
+++ b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/Artemis.java
@@ -28,14 +28,14 @@ import org.apache.activemq.artemis.cli.commands.Stop;
import java.io.InputStream;
import java.io.OutputStream;
-public class ActiveMQ
+public class Artemis
{
public static void main(String[] args) throws Exception
{
- String instance = System.getProperty("activemq.instance");
- Cli.CliBuilder builder = Cli.builder("activemq")
- .withDescription("ActiveMQ Command Line")
+ String instance = System.getProperty("artemis.instance");
+ Cli.CliBuilder builder = Cli.builder("artemis")
+ .withDescription("ActiveMQ Artemis Command Line")
.withCommand(HelpAction.class)
.withDefaultCommand(HelpAction.class);
@@ -67,14 +67,14 @@ public class ActiveMQ
{
System.err.println(configException.getMessage());
System.out.println();
- System.out.println("Configuration should be specified as 'scheme:location'. Default configuration is 'xml:${ACTIVEMQ_INSTANCE}/etc/bootstrap.xml'");
+ System.out.println("Configuration should be specified as 'scheme:location'. Default configuration is 'xml:${ARTEMIS_INSTANCE}/etc/bootstrap.xml'");
}
}
public static void printBanner() throws Exception
{
- copy(ActiveMQ.class.getResourceAsStream("banner.txt"), System.out);
+ copy(Artemis.class.getResourceAsStream("banner.txt"), System.out);
}
private static long copy(InputStream in, OutputStream out) throws Exception
diff --git a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Create.java b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Create.java
index 22cc10edfe..8131668159 100644
--- a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Create.java
+++ b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Create.java
@@ -44,7 +44,7 @@ public class Create implements Action
@Option(name = "--force", description = "Overwrite configuration at destination directory")
boolean force;
- @Option(name = "--home", description = "Directory where ActiveMQ is installed")
+ @Option(name = "--home", description = "Directory where ActiveMQ Artemis is installed")
File home;
@Option(name = "--with-ssl", description = "Generate an SSL enabled configuration")
@@ -91,7 +91,7 @@ public class Create implements Action
}
- context.out.println(String.format("Creating ActiveMQ instance at: %s", directory.getCanonicalPath()));
+ context.out.println(String.format("Creating ActiveMQ Artemis instance at: %s", directory.getCanonicalPath()));
if (host == null)
{
host = directory.getName();
@@ -128,8 +128,8 @@ public class Create implements Action
{
filters.put("${home}", path(home, false));
}
- filters.put("${activemq.home}", path(System.getProperty("activemq.home"), false));
- filters.put("${activemq.instance}", path(directory, false));
+ filters.put("${artemis.home}", path(System.getProperty("artemis.home"), false));
+ filters.put("${artemis.instance}", path(directory, false));
filters.put("${java.home}", path(System.getProperty("java.home"), false));
new File(directory, "bin").mkdirs();
@@ -141,20 +141,20 @@ public class Create implements Action
if (IS_WINDOWS)
{
- write("bin/activemq.cmd", null, false);
- write("bin/activemq-service.exe");
- write("bin/activemq-service.xml", filters, false);
- write("etc/activemq.profile.cmd", filters, false);
+ write("bin/artemis.cmd", null, false);
+ write("bin/artemis-service.exe");
+ write("bin/artemis-service.xml", filters, false);
+ write("etc/artemis.profile.cmd", filters, false);
}
if (!IS_WINDOWS || IS_CYGWIN)
{
- write("bin/activemq", null, true);
- makeExec("bin/activemq");
- write("bin/activemq-service", null, true);
- makeExec("bin/activemq-service");
- write("etc/activemq.profile", filters, true);
- makeExec("etc/activemq.profile");
+ write("bin/artemis", null, true);
+ makeExec("bin/artemis");
+ write("bin/artemis-service", null, true);
+ makeExec("bin/artemis-service");
+ write("etc/artemis.profile", filters, true);
+ makeExec("etc/artemis.profile");
}
write("etc/logging.properties", null, false);
@@ -166,9 +166,9 @@ public class Create implements Action
context.out.println("");
context.out.println("You can now start the broker by executing: ");
context.out.println("");
- context.out.println(String.format(" \"%s\" run", path(new File(directory, "bin/activemq"), true)));
+ context.out.println(String.format(" \"%s\" run", path(new File(directory, "bin/artemis"), true)));
- File service = new File(directory, "bin/activemq-service");
+ File service = new File(directory, "bin/artemis-service");
context.out.println("");
if (!IS_WINDOWS || IS_CYGWIN)
@@ -180,7 +180,7 @@ public class Create implements Action
context.out.println("Or you can setup the broker as system service and run it in the background:");
context.out.println("");
context.out.println(" sudo ln -s \"%s\" /etc/init.d/".format(service.getCanonicalPath()));
- context.out.println(" /etc/init.d/activemq-service start");
+ context.out.println(" /etc/init.d/artemis-service start");
context.out.println("");
}
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis
similarity index 71%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis
index c72af5b41b..7b6dfcd0a6 100755
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis
@@ -16,7 +16,7 @@
# specific language governing permissions and limitations
# under the License.
-if [ -z "$ACTIVEMQ_INSTANCE" ] ; then
+if [ -z "$ARTEMIS_INSTANCE" ] ; then
## resolve links - $0 may be a link to ActiveMQ's home
PRG="$0"
@@ -37,23 +37,23 @@ if [ -z "$ACTIVEMQ_INSTANCE" ] ; then
fi
done
- ACTIVEMQ_INSTANCE=`dirname "$PRG"`
+ ARTEMIS_INSTANCE=`dirname "$PRG"`
cd "$saveddir"
# make it fully qualified
- ACTIVEMQ_INSTANCE=`cd "$ACTIVEMQ_INSTANCE/.." && pwd`
+ ARTEMIS_INSTANCE=`cd "$ARTEMIS_INSTANCE/.." && pwd`
fi
# Set Defaults Properties
-ACTIVEMQ_LOGGING_CONF="file:$ACTIVEMQ_INSTANCE/etc/logging.properties"
-ACTIVEMQ_DATA_DIR="$ACTIVEMQ_INSTANCE/data"
-ACTIVEMQ_LOG_MANAGER=org.jboss.logmanager.LogManager
+ARTEMIS_LOGGING_CONF="file:$ARTEMIS_INSTANCE/etc/logging.properties"
+ARTEMIS_DATA_DIR="$ARTEMIS_INSTANCE/data"
+ARTEMIS_LOG_MANAGER=org.jboss.logmanager.LogManager
JAVA_ARGS="-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M"
# Load Profile Data
-. "$ACTIVEMQ_INSTANCE/etc/activemq.profile"
+. "$ARTEMIS_INSTANCE/etc/artemis.profile"
-CLASSPATH="$ACTIVEMQ_HOME/lib/artemis-boot.jar"
+CLASSPATH="$ARTEMIS_HOME/lib/artemis-boot.jar"
# OS specific support.
cygwin=false;
@@ -72,8 +72,8 @@ esac
# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
- [ -n "$ACTIVEMQ_INSTANCE" ] &&
- ACTIVEMQ_INSTANCE=`cygpath --unix "$ACTIVEMQ_INSTANCE"`
+ [ -n "$ARTEMIS_INSTANCE" ] &&
+ ARTEMIS_INSTANCE=`cygpath --unix "$ARTEMIS_INSTANCE"`
[ -n "$JAVA_HOME" ] &&
JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
fi
@@ -102,18 +102,18 @@ fi
if $cygwin ; then
JAVA_HOME=`cygpath --windows "$JAVA_HOME"`
- ACTIVEMQ_HOME=`cygpath --windows "$ACTIVEMQ_HOME"`
+ ARTEMIS_HOME=`cygpath --windows "$ARTEMIS_HOME"`
CLASSPATH=`cygpath --windows "$CLASSPATH"`
fi
-exec "$JAVACMD" $JAVA_ARGS $ACTIVEMQ_CLUSTER_PROPS \
+exec "$JAVACMD" $JAVA_ARGS $ARTEMIS_CLUSTER_PROPS \
-classpath "$CLASSPATH" \
- -Dactivemq.home="$ACTIVEMQ_HOME" \
- -Dactivemq.instance="$ACTIVEMQ_INSTANCE" \
- -Djava.library.path="$ACTIVEMQ_HOME/bin/lib/linux-i686:$ACTIVEMQ_INSTANCE/bin/lib/linux-x86_64" \
- -Djava.io.tmpdir="$ACTIVEMQ_INSTANCE/tmp" \
- -Ddata.dir="$ACTIVEMQ_DATA_DIR" \
- -Djava.util.logging.manager="$ACTIVEMQ_LOG_MANAGER" \
- -Dlogging.configuration="$ACTIVEMQ_LOGGING_CONF" \
+ -Dartemis.home="$ARTEMIS_HOME" \
+ -Dartemis.instance="$ARTEMIS_INSTANCE" \
+ -Djava.library.path="$ARTEMIS_HOME/bin/lib/linux-i686:$ARTEMIS_INSTANCE/bin/lib/linux-x86_64" \
+ -Djava.io.tmpdir="$ARTEMIS_INSTANCE/tmp" \
+ -Ddata.dir="$ARTEMIS_DATA_DIR" \
+ -Djava.util.logging.manager="$ARTEMIS_LOG_MANAGER" \
+ -Dlogging.configuration="$ARTEMIS_LOGGING_CONF" \
$DEBUG_ARGS \
- org.apache.activemq.artemis.boot.ActiveMQ $@
+ org.apache.activemq.artemis.boot.Artemis $@
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service
similarity index 86%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service
index 84235c95c0..7a53901ae8 100755
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service
@@ -19,9 +19,9 @@
service=`basename "$0"`
#
-# Discover the ACTIVEMQ_INSTANCE from the location of this script.
+# Discover the ARTEMIS_INSTANCE from the location of this script.
#
-if [ -z "$ACTIVEMQ_INSTANCE" ] ; then
+if [ -z "$ARTEMIS_INSTANCE" ] ; then
## resolve links - $0 may be a link to ActiveMQ's home
PRG="$0"
@@ -41,19 +41,19 @@ if [ -z "$ACTIVEMQ_INSTANCE" ] ; then
fi
done
- ACTIVEMQ_INSTANCE=`dirname "$PRG"`
+ ARTEMIS_INSTANCE=`dirname "$PRG"`
cd "$saveddir"
# make it fully qualified
- ACTIVEMQ_INSTANCE=`cd "$ACTIVEMQ_INSTANCE/.." && pwd`
- export ACTIVEMQ_INSTANCE
+ ARTEMIS_INSTANCE=`cd "$ARTEMIS_INSTANCE/.." && pwd`
+ export ARTEMIS_INSTANCE
fi
-PID_FILE="${ACTIVEMQ_INSTANCE}/data/activemq.pid"
+PID_FILE="${ARTEMIS_INSTANCE}/data/artemis.pid"
-if [ ! -d "${ACTIVEMQ_INSTANCE}/data/" ]; then
- mkdir "${ACTIVEMQ_INSTANCE}/data/"
+if [ ! -d "${ARTEMIS_INSTANCE}/data/" ]; then
+ mkdir "${ARTEMIS_INSTANCE}/data/"
fi
status() {
@@ -95,7 +95,7 @@ start() {
return 1
fi
- nohup ${ACTIVEMQ_INSTANCE}/bin/activemq run > /dev/null 2> /dev/null &
+ nohup ${ARTEMIS_INSTANCE}/bin/artemis run > /dev/null 2> /dev/null &
echo $! > "${PID_FILE}"
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service.xml b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service.xml
similarity index 68%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service.xml
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service.xml
index 12dc6ce44b..a39d16f943 100644
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq-service.xml
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis-service.xml
@@ -18,11 +18,11 @@
-->
- activemq-${host}
- ActiveMQ: ${host}
+ armetis-${host}
+ ActiveMQ Artemis: ${host}
Apache ActiveMQ Artemis is a reliable messaging broker
- ${activemq.instance}\log
+ ${artemis.instance}\log
roll
"${java.home}\bin\java.exe"
@@ -33,26 +33,26 @@
-Xmx1024M
-classpath
- "${activemq.home}\lib\artemis-boot.jar"
- "-Dactivemq.home=${activemq.home}"
- "-Dactivemq.instance=${activemq.instance}"
- "-Ddata.dir=${activemq.instance}/data"
+ "${artemis.home}\lib\artemis-boot.jar"
+ "-artemis.home=${artemis.home}"
+ "-artemis.instance=${artemis.instance}"
+ "-Ddata.dir=${artemis.instance}/data"
-Djava.util.logging.manager=org.jboss.logmanager.LogManager
- "-Dlogging.configuration=file:${activemq.instance}\etc\logging.properties"
+ "-Dlogging.configuration=file:${artemis.instance}\etc\logging.properties"
- ActiveMQ
+ Armetis
run
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq.cmd b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis.cmd
similarity index 58%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq.cmd
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis.cmd
index fd56f09ae4..5e8f5000cc 100755
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/activemq.cmd
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/bin/artemis.cmd
@@ -18,17 +18,17 @@ rem under the License.
setlocal
-if NOT "%ACTIVEMQ_INSTANCE%"=="" goto CHECK_ACTIVEMQ_INSTANCE
+if NOT "%ARTEMIS_INSTANCE%"=="" goto CHECK_ARTEMIS_INSTANCE
PUSHD .
CD %~dp0..
-set ACTIVEMQ_INSTANCE=%CD%
+set ARTEMIS_INSTANCE=%CD%
POPD
-:CHECK_ACTIVEMQ_INSTANCE
-if exist "%ACTIVEMQ_INSTANCE%\bin\activemq.cmd" goto CHECK_JAVA
+:CHECK_ARTEMIS_INSTANCE
+if exist "%ARTEMIS_INSTANCE%\bin\activemq.cmd" goto CHECK_JAVA
:NO_HOME
-echo ACTIVEMQ_INSTANCE environment variable is set incorrectly. Please set ACTIVEMQ_INSTANCE.
+echo ARTEMIS_INSTANCE environment variable is set incorrectly. Please set ARTEMIS_INSTANCE.
goto END
:CHECK_JAVA
@@ -49,25 +49,25 @@ echo.
rem "Set Defaults."
set JAVA_ARGS=-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M
-set ACTIVEMQ_LOGGING_CONF=file:%ACTIVEMQ_INSTANCE%\etc\logging.properties
-set ACTIVEMQ_DATA_DIR=%ACTIVEMQ_INSTANCE%\data
-set ACTIVEMQ_LOG_MANAGER=org.jboss.logmanager.LogManager
+set ARTEMIS_LOGGING_CONF=file:%ARTEMIS_INSTANCE%\etc\logging.properties
+set ARTEMIS_DATA_DIR=%ARTEMIS_INSTANCE%\data
+set ARTEMIS_LOG_MANAGER=org.jboss.logmanager.LogManager
rem "Load Profile Config"
-call "%ACTIVEMQ_INSTANCE%\etc\activemq.profile.cmd" %*
+call "%ARTEMIS_INSTANCE%\etc\artemis.profile.cmd" %*
rem "Create full JVM Args"
set JVM_ARGS=%JAVA_ARGS%
-if not "%ACTIVEMQ_CLUSTER_PROPS%"=="" set JVM_ARGS=%JVM_ARGS% %ACTIVEMQ_CLUSTER_PROPS%
-set JVM_ARGS=%JVM_ARGS% -classpath "%ACTIVEMQ_HOME%\lib\artemis-boot.jar"
-set JVM_ARGS=%JVM_ARGS% -Dactivemq.home="%ACTIVEMQ_HOME%"
-set JVM_ARGS=%JVM_ARGS% -Dactivemq.instance="%ACTIVEMQ_INSTANCE%"
-set JVM_ARGS=%JVM_ARGS% -Ddata.dir="%ACTIVEMQ_DATA_DIR%"
-set JVM_ARGS=%JVM_ARGS% -Djava.util.logging.manager="%ACTIVEMQ_LOG_MANAGER%"
-set JVM_ARGS=%JVM_ARGS% -Dlogging.configuration="%ACTIVEMQ_LOGGING_CONF%"
+if not "%ARTEMIS_CLUSTER_PROPS%"=="" set JVM_ARGS=%JVM_ARGS% %ARTEMIS_CLUSTER_PROPS%
+set JVM_ARGS=%JVM_ARGS% -classpath "%ARTEMIS_HOME%\lib\artemis-boot.jar"
+set JVM_ARGS=%JVM_ARGS% -Dartemis.home="%ARTEMIS_HOME%"
+set JVM_ARGS=%JVM_ARGS% -Dartemis.instance="%ARTEMIS_INSTANCE%"
+set JVM_ARGS=%JVM_ARGS% -Ddata.dir="%ARTEMIS_DATA_DIR%"
+set JVM_ARGS=%JVM_ARGS% -Djava.util.logging.manager="%ARTEMIS_LOG_MANAGER%"
+set JVM_ARGS=%JVM_ARGS% -Dlogging.configuration="%ARTEMIS_LOGGING_CONF%"
if not "%DEBUG_ARGS%"=="" set JVM_ARGS=%JVM_ARGS% %DEBUG_ARGS%
-"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.artemis.boot.ActiveMQ %*
+"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.artemis.boot.Artemis %*
:END
endlocal
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile
similarity index 84%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile
index 755fec1055..889a0a9eec 100644
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile
@@ -15,10 +15,10 @@
# specific language governing permissions and limitations
# under the License.
-ACTIVEMQ_HOME='${activemq.home}'
+ARTEMIS_HOME='${artemis.home}'
# Cluster Properties: Used to pass arguments to ActiveMQ which can be referenced in broker.xml
-#ACTIVEMQ_CLUSTER_PROPS="-Dactivemq.remoting.default.port=61617 -Dactivemq.remoting.amqp.port=5673 -Dactivemq.remoting.stomp.port=61614 -Dactivemq.remoting.hornetq.port=5446"
+#ARTEMIS_CLUSTER_PROPS="-Dactivemq.remoting.default.port=61617 -Dactivemq.remoting.amqp.port=5673 -Dactivemq.remoting.stomp.port=61614 -Dactivemq.remoting.hornetq.port=5446"
# Java Opts
#JAVA_ARGS="-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M"
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile.cmd b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile.cmd
similarity index 84%
rename from artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile.cmd
rename to artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile.cmd
index 3c2856493d..450ba792dc 100644
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/activemq.profile.cmd
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/artemis.profile.cmd
@@ -15,10 +15,10 @@ rem KIND, either express or implied. See the License for the
rem specific language governing permissions and limitations
rem under the License.
-set ACTIVEMQ_HOME=${activemq.home}
+set ARTEMIS_HOME=${artemis.home}
rem Cluster Properties: Used to pass arguments to ActiveMQ which can be referenced in broker.xml
-rem set ACTIVEMQ_CLUSTER_PROPS=-Dactivemq.remoting.default.port=61617 -Dactivemq.remoting.amqp.port=5673 -Dactivemq.remoting.stomp.port=61614 -Dactivemq.remoting.hornetq.port=5446
+rem set ARTEMIS_CLUSTER_PROPS=-Dactivemq.remoting.default.port=61617 -Dactivemq.remoting.amqp.port=5673 -Dactivemq.remoting.stomp.port=61614 -Dactivemq.remoting.hornetq.port=5446
rem Java Opts
rem set JAVA_ARGS=-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/bootstrap.xml b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/bootstrap.xml
index 530db62c3a..14924250de 100644
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/bootstrap.xml
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/bootstrap.xml
@@ -19,12 +19,12 @@
-
+
diff --git a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/logging.properties b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/logging.properties
index f4f4a814d7..084b74c2ad 100644
--- a/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/logging.properties
+++ b/artemis-bootstrap/src/main/resources/org/apache/activemq/artemis/cli/commands/etc/logging.properties
@@ -42,7 +42,7 @@ handler.FILE=org.jboss.logmanager.handlers.FileHandler
handler.FILE.level=DEBUG
handler.FILE.properties=autoFlush,fileName
handler.FILE.autoFlush=true
-handler.FILE.fileName=${activemq.instance}/log/activemq.log
+handler.FILE.fileName=${artemis.instance}/log/activemq.log
handler.FILE.formatter=PATTERN
# Formatter pattern configuration
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
index 32cd969249..7b2f7e8d47 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
@@ -40,7 +40,7 @@ public class ActiveMQXAResourceWrapperImplTest
xaResourceWrapperProperties.put(ActiveMQXAResourceWrapper.ACTIVEMQ_JNDI_NAME, jndiName);
xaResourceWrapperProperties.put(ActiveMQXAResourceWrapper.ACTIVEMQ_NODE_ID, nodeId);
xaResourceWrapperProperties.put(ActiveMQXAResourceWrapper.ACTIVEMQ_PRODUCT_VERSION, "6");
- xaResourceWrapperProperties.put(ActiveMQXAResourceWrapper.ACTIVEMQ_PRODUCT_NAME, "ActiveMQ");
+ xaResourceWrapperProperties.put(ActiveMQXAResourceWrapper.ACTIVEMQ_PRODUCT_NAME, "ActiveMQ Artemis");
ActiveMQXAResourceWrapperImpl xaResourceWrapper = new ActiveMQXAResourceWrapperImpl(xaResource, xaResourceWrapperProperties);
String expectedJndiNodeId = jndiName + " NodeId:" + nodeId;
diff --git a/artemis-website/src/main/resources/examples/index.html b/artemis-website/src/main/resources/examples/index.html
index 2c2a7469fd..f9875a35de 100644
--- a/artemis-website/src/main/resources/examples/index.html
+++ b/artemis-website/src/main/resources/examples/index.html
@@ -60,7 +60,7 @@
to run a different example simply edit the config/examples/bootstrap.xml
aand change the paths to point
the correct configuration (this will be found in the directory of the example you wish to run). By default the broker
will use the data/server0
directory for the journal, to avoid problems it is best to delete this
- directory between running different examples or set the ACTIVEMQ_DATA_DIR
environment property in
+ directory between running different examples or set the ARTEMIS_DATA_DIR
environment property in
activemq.conf
to use a different location
diff --git a/distribution/artemis/src/main/resources/bin/activemq b/distribution/artemis/src/main/resources/bin/artemis
similarity index 82%
rename from distribution/artemis/src/main/resources/bin/activemq
rename to distribution/artemis/src/main/resources/bin/artemis
index ab76baca67..f31e35163a 100755
--- a/distribution/artemis/src/main/resources/bin/activemq
+++ b/distribution/artemis/src/main/resources/bin/artemis
@@ -16,7 +16,7 @@
# specific language governing permissions and limitations
# under the License.
-if [ -z "$ACTIVEMQ_HOME" ] ; then
+if [ -z "$ARTEMIS_HOME" ] ; then
## resolve links - $0 may be a link to ActiveMQ's home
PRG="$0"
@@ -37,16 +37,16 @@ if [ -z "$ACTIVEMQ_HOME" ] ; then
fi
done
- ACTIVEMQ_HOME=`dirname "$PRG"`
+ ARTEMIS_HOME=`dirname "$PRG"`
cd "$saveddir"
# make it fully qualified
- ACTIVEMQ_HOME=`cd "$ACTIVEMQ_HOME/.." && pwd`
+ ARTEMIS_HOME=`cd "$ARTEMIS_HOME/.." && pwd`
fi
# Set Defaults Properties
JAVA_ARGS="-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M"
-CLASSPATH="$ACTIVEMQ_HOME/lib/artemis-boot.jar"
+CLASSPATH="$ARTEMIS_HOME/lib/artemis-boot.jar"
# OS specific support.
cygwin=false;
@@ -65,8 +65,8 @@ esac
# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
- [ -n "$ACTIVEMQ_HOME" ] &&
- ACTIVEMQ_HOME=`cygpath --unix "$ACTIVEMQ_HOME"`
+ [ -n "$ARTEMIS_HOME" ] &&
+ ARTEMIS_HOME=`cygpath --unix "$ARTEMIS_HOME"`
[ -n "$JAVA_HOME" ] &&
JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
fi
@@ -96,13 +96,13 @@ fi
if $cygwin ; then
JAVA_HOME=`cygpath --windows "$JAVA_HOME"`
- ACTIVEMQ_HOME=`cygpath --windows "$ACTIVEMQ_HOME"`
+ ARTEMIS_HOME=`cygpath --windows "$ARTEMIS_HOME"`
CLASSPATH=`cygpath --windows "$CLASSPATH"`
fi
-exec "$JAVACMD" $JAVA_ARGS $ACTIVEMQ_CLUSTER_PROPS \
+exec "$JAVACMD" $JAVA_ARGS $ARTEMIS_CLUSTER_PROPS \
-classpath "$CLASSPATH" \
- -Dactivemq.home="$ACTIVEMQ_HOME" \
- -Djava.library.path="$ACTIVEMQ_HOME/bin/lib/linux-i686:$ACTIVEMQ_INSTANCE/bin/lib/linux-x86_64" \
+ -Dartemis.home="$ARTEMIS_HOME" \
+ -Djava.library.path="$ARTEMIS_HOME/bin/lib/linux-i686:$ARTEMIS_INSTANCE/bin/lib/linux-x86_64" \
$DEBUG_ARGS \
- org.apache.activemq.artemis.boot.ActiveMQ $@
+ org.apache.activemq.artemis.boot.Artemis $@
diff --git a/distribution/artemis/src/main/resources/bin/activemq.cmd b/distribution/artemis/src/main/resources/bin/artemis.cmd
similarity index 73%
rename from distribution/artemis/src/main/resources/bin/activemq.cmd
rename to distribution/artemis/src/main/resources/bin/artemis.cmd
index 344c9df4a9..4132fb630a 100755
--- a/distribution/artemis/src/main/resources/bin/activemq.cmd
+++ b/distribution/artemis/src/main/resources/bin/artemis.cmd
@@ -18,17 +18,17 @@ rem under the License.
setlocal
-if NOT "%ACTIVEMQ_HOME%"=="" goto CHECK_ACTIVEMQ_HOME
+if NOT "%ARTEMIS_HOME%"=="" goto CHECK_ARTEMIS_HOME
PUSHD .
CD %~dp0..
-set ACTIVEMQ_HOME=%CD%
+set ARTEMIS_HOME=%CD%
POPD
-:CHECK_ACTIVEMQ_HOME
-if exist "%ACTIVEMQ_HOME%\bin\activemq.cmd" goto CHECK_JAVA
+:CHECK_ARTEMIS_HOME
+if exist "%ARTEMIS_HOME%\bin\artemis.cmd" goto CHECK_JAVA
:NO_HOME
-echo ACTIVEMQ_HOME environment variable is set incorrectly. Please set ACTIVEMQ_HOME.
+echo ARTEMIS_HOME environment variable is set incorrectly. Please set ARTEMIS_HOME.
goto END
:CHECK_JAVA
@@ -52,12 +52,12 @@ set JAVA_ARGS=-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods
rem "Create full JVM Args"
set JVM_ARGS=%JAVA_ARGS%
-if not "%ACTIVEMQ_CLUSTER_PROPS%"=="" set JVM_ARGS=%JVM_ARGS% %ACTIVEMQ_CLUSTER_PROPS%
-set JVM_ARGS=%JVM_ARGS% -classpath "%ACTIVEMQ_HOME%\lib\artemis-boot.jar"
-set JVM_ARGS=%JVM_ARGS% -Dactivemq.home="%ACTIVEMQ_HOME%"
+if not "%ARTEMIS_CLUSTER_PROPS%"=="" set JVM_ARGS=%JVM_ARGS% %ARTEMIS_CLUSTER_PROPS%
+set JVM_ARGS=%JVM_ARGS% -classpath "%ARTEMIS_HOME%\lib\artemis-boot.jar"
+set JVM_ARGS=%JVM_ARGS% -Dartemis.home="%ARTEMIS_HOME%"
if not "%DEBUG_ARGS%"=="" set JVM_ARGS=%JVM_ARGS% %DEBUG_ARGS%
-"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.artemis.boot.ActiveMQ %*
+"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.artemis.boot.Artemis %*
:END
endlocal
diff --git a/docs/quickstart-guide/en/running.md b/docs/quickstart-guide/en/running.md
index 0a9a0d9bdd..5bd483af6b 100644
--- a/docs/quickstart-guide/en/running.md
+++ b/docs/quickstart-guide/en/running.md
@@ -4,7 +4,7 @@ Creating a Broker Instance
A broker instance is the directory containing all the configuration and runtime
data, such as logs and data files, associated with a broker process. It is recommended that
-you do *not* create the instance directory under `${ACTIVEMQ_HOME}`. This separation is
+you do *not* create the instance directory under `${ARTEMIS_HOME}`. This separation is
encouraged so that you can more easily upgrade when the next version of ActiveMQ is released.
On Unix systems, it is a common convention to store this kind of runtime data under
@@ -12,7 +12,7 @@ the `/var/lib` directory. For example, to create an instance at '/var/lib/mybro
the following commands in your command line shell:
cd /var/lib
- ${ACTIVEMQ_HOME}/bin/activemq create mybroker
+ ${ARTEMIS_HOME}/bin/activemq create mybroker
A broker instance directory will contain the following sub directories:
diff --git a/docs/user-manual/en/using-server.md b/docs/user-manual/en/using-server.md
index 9f7a37bca3..cbae852546 100644
--- a/docs/user-manual/en/using-server.md
+++ b/docs/user-manual/en/using-server.md
@@ -10,13 +10,13 @@ we mean the Apache ActiveMQ Artemis standalone server, in its default configurat
with a JMS Service enabled.
This document will refer to the full path of the directory where the ActiveMQ
-distribution has been extracted to as `${ACTIVEMQ_HOME}` directory.
+distribution has been extracted to as `${ARTEMIS_HOME}` directory.
## Creating a Broker Instance
A broker instance is the directory containing all the configuration and runtime
data, such as logs and data files, associated with a broker process. It is recommended that
-you do *not* create the instance directory under `${ACTIVEMQ_HOME}`. This separation is
+you do *not* create the instance directory under `${ARTEMIS_HOME}`. This separation is
encouraged so that you can more easily upgrade when the next version of ActiveMQ is released.
On Unix systems, it is a common convention to store this kind of runtime data under
@@ -24,7 +24,7 @@ the `/var/lib` directory. For example, to create an instance at '/var/lib/mybro
the following commands in your command line shell:
cd /var/lib
- ${ACTIVEMQ_HOME}/bin/activemq create mybroker
+ ${ARTEMIS_HOME}/bin/activemq create mybroker
A broker instance directory will contain the following sub directories:
diff --git a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Run.java b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Run.java
index a8e505c6ff..360ed3b975 100644
--- a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Run.java
+++ b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Run.java
@@ -19,7 +19,7 @@ package org.apache.activemq.artemis.cli.commands;
import io.airlift.command.Arguments;
import io.airlift.command.Command;
-import org.apache.activemq.artemis.cli.ActiveMQ;
+import org.apache.activemq.artemis.cli.Artemis;
import org.apache.activemq.artemis.components.ExternalComponent;
import org.apache.activemq.artemis.core.server.ActiveMQComponent;
import org.apache.activemq.artemis.dto.BrokerDTO;
@@ -40,7 +40,7 @@ import java.util.TimerTask;
public class Run implements Action
{
- @Arguments(description = "Broker Configuration URI, default 'xml:${ACTIVEMQ_INSTANCE}/etc/bootstrap.xml'")
+ @Arguments(description = "Broker Configuration URI, default 'xml:${ARTEMIS_INSTANCE}/etc/bootstrap.xml'")
String configuration;
private ArrayList components = new ArrayList<>();
@@ -60,13 +60,13 @@ public class Run implements Action
public Object execute(ActionContext context) throws Exception
{
- ActiveMQ.printBanner();
+ Artemis.printBanner();
- /* We use File URI for locating files. The ACTIVEMQ_HOME variable is used to determine file paths. For Windows
- the ACTIVEMQ_HOME variable will include back slashes (An invalid file URI character path separator). For this
- reason we overwrite the ACTIVEMQ_HOME variable with backslashes replaced with forward slashes. */
- String activemqInstance = System.getProperty("activemq.instance").replace("\\", "/");
- System.setProperty("activemq.instance", activemqInstance);
+ /* We use File URI for locating files. The ARTEMIS_HOME variable is used to determine file paths. For Windows
+ the ARTEMIS_HOME variable will include back slashes (An invalid file URI character path separator). For this
+ reason we overwrite the ARTEMIS_HOME variable with backslashes replaced with forward slashes. */
+ String activemqInstance = System.getProperty("artemis.instance").replace("\\", "/");
+ System.setProperty("artemis.instance", activemqInstance);
if (configuration == null)
{
@@ -120,7 +120,7 @@ public class Run implements Action
ActiveMQBootstrapLogger.LOGGER.errorDeletingFile(file.getAbsolutePath());
}
}
- final Timer timer = new Timer("ActiveMQ Server Shutdown Timer", true);
+ final Timer timer = new Timer("ActiveMQ Artemis Server Shutdown Timer", true);
timer.scheduleAtFixedRate(new TimerTask()
{
@Override
diff --git a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Stop.java b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Stop.java
index 0c4028c00c..90cddb37cb 100644
--- a/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Stop.java
+++ b/artemis-bootstrap/src/main/java/org/apache/activemq/artemis/cli/commands/Stop.java
@@ -27,17 +27,17 @@ import java.net.URI;
@Command(name = "stop", description = "stops the broker instance")
public class Stop implements Action
{
- @Arguments(description = "Broker Configuration URI, default 'xml:${ACTIVEMQ_INSTANCE}/etc/bootstrap.xml'")
+ @Arguments(description = "Broker Configuration URI, default 'xml:${ARTEMIS_INSTANCE}/etc/bootstrap.xml'")
String configuration;
@Override
public Object execute(ActionContext context) throws Exception
{
- /* We use File URI for locating files. The ACTIVEMQ_HOME variable is used to determine file paths. For Windows
- the ACTIVEMQ_HOME variable will include back slashes (An invalid file URI character path separator). For this
- reason we overwrite the ACTIVEMQ_HOME variable with backslashes replaced with forward slashes. */
- String activemqHome = System.getProperty("activemq.instance").replace("\\", "/");
- System.setProperty("activemq.instance", activemqHome);
+ /* We use File URI for locating files. The ARTEMIS_HOME variable is used to determine file paths. For Windows
+ the ARTEMIS_HOME variable will include back slashes (An invalid file URI character path separator). For this
+ reason we overwrite the ARTEMIS_HOME variable with backslashes replaced with forward slashes. */
+ String activemqHome = System.getProperty("artemis.instance").replace("\\", "/");
+ System.setProperty("artemis.instance", activemqHome);
if (configuration == null)
{